@@ -2,7 +2,8 @@ import csv
 import itertools
 from pathlib import Path
 
-from qtpy.QtWidgets import QWidget, QVBoxLayout, QDialog
+from PyQt5.QtWidgets import QFrame
+from qtpy.QtWidgets import QVBoxLayout, QDialog
 
 from napari_allencell_annotator.controller.images_controller import ImagesController
 
@@ -12,7 +13,7 @@ import napari
 from typing import List, Dict, Union
 
 
-class MainController(QWidget):
+class MainController(QFrame):
     """
     A class used to combine/communicate between AnnotatorController and ViewController.
 
@@ -35,7 +36,7 @@ class MainController(QWidget):
         self.images = ImagesController(self.napari)
         self.annots = AnnotatorController(self.napari)
         self.layout.addWidget(self.images.view, stretch=1)
-        self.layout.addWidget(self.annots.view, stretch=2)
+        self.layout.addWidget(self.annots.view, stretch=1)
         self.setLayout(self.layout)
         self.show()
 
@@ -450,16 +451,6 @@ class MainController(QWidget):
         self.images.next_img()
         self.annots.set_curr_img(self.images.curr_img_dict())
 
-    def _image_selected(self, current, previous):
-        """
-        Record the annotations for the previously selected image and set current image.
-
-        Called only when annotating un-blind and users select an image from the list.
-        """
-        if previous:
-            self.annots.record_annotations(previous.file_path)
-        self.annots.set_curr_img(self.images.curr_img_dict())
-
     def _prev_image_clicked(self):
         """
         Move to the previous image for annotating.
@@ -470,6 +461,16 @@ class MainController(QWidget):
         self.images.prev_img()
         self.annots.set_curr_img(self.images.curr_img_dict())
 
+    def _image_selected(self, current, previous):
+        """
+        Record the annotations for the previously selected image and set current image.
+
+        Called only when annotating un-blind and users select an image from the list.
+        """
+        if previous:
+            self.annots.record_annotations(previous.file_path)
+        self.annots.set_curr_img(self.images.curr_img_dict())
+
     def _save_and_exit_clicked(self):
         """Stop annotation if user confirms choice in popup."""
         proceed: bool = self.annots.view.popup("Close this session?")
