@@ -1,10 +1,9 @@
-from typing import List
+from typing import Set
 
+from PyQt5.QtWidgets import QFrame
 from qtpy.QtCore import Qt
-from qtpy.QtGui import QFont
 
 from qtpy.QtWidgets import (
-    QWidget,
     QLabel,
     QScrollArea,
     QGridLayout,
@@ -21,9 +20,10 @@ from napari_allencell_annotator.widgets.file_input import (
 )
 from napari_allencell_annotator.widgets.scrollable_popup import ScrollablePopup
 from napari_allencell_annotator.widgets.files_widget import FilesWidget, FileItem
+from napari_allencell_annotator._style import Style
 
 
-class ImagesView(QWidget):
+class ImagesView(QFrame):
     """
     A class used to create a view for image file uploading and selecting.
 
@@ -47,15 +47,15 @@ class ImagesView(QWidget):
         viewer : napari.Viewer
             The napari viewer for the plugin
         ctrl : ImagesController
-            The controller
+            The images controller
         """
         super().__init__()
 
+        self.setStyleSheet(Style.get_stylesheet("main.qss"))
         self.label = QLabel()
         self.label.setAlignment(Qt.AlignCenter)
         self.label.setText("Images")
 
-        self.label.setFont(QFont("Arial", 15))
         self.layout = QGridLayout()
         self.layout.addWidget(self.label, 0, 0, 1, 4)
 
@@ -126,10 +126,10 @@ class ImagesView(QWidget):
         """Ask user to approve a list of files to delete from the file list."""
         if len(self.file_widget.checked) > 0:
             msg: str = "Delete these files from the list?"
-            lst: List[str] = []
+            names: Set[str] = set()
             for item in self.file_widget.checked:
-                lst.append("--- " + item.file_path)
-            msg_box = ScrollablePopup(msg, lst)
+                names.add("--- " + item.file_path)
+            msg_box = ScrollablePopup(msg, names)
             if msg_box.exec() == QDialog.Accepted:
                 self.file_widget.delete_checked()
         else:
@@ -197,5 +197,5 @@ class ImagesView(QWidget):
             except exceptions.UnsupportedFileFormatError:
                 self.alert("AICS Unsupported File Type")
             except FileNotFoundError:
-                self.alert("File no longer exists")
+                self.alert("File Not Found")
                 self.file_widget.remove_item(current)
